# ibpmgenerate - generate bad pixel mask from flat field images
# Author : Robert Greimel (greimel@ing.iac.es)
# Last Change : 16. Aug. 2000
##############################################################################
procedure ibpmgenerate(flat1,flat2,output)

string	flat1	{prompt="First flat field image"}
string	flat2	{prompt="Second flat field image"}
string	output	{prompt="output pixel mask"}
bool	verbose	{prompt="Verbose ?"}
bool	info	{prompt="Informative messages ?"}
string	tmpdir	{prompt="temporary directory for file conversion"}

begin
  string	if1,if2,ino
  string	diffile
  bool		bf1,bf2

  # copy input arguments to force definition at the beginning of the script
  if1 = flat1
  if2 = flat2
  ino = output

  # setup variables
  bf1 = no
  bf2 = no

  # switch info on if verbose is set to yes
  if ( verbose ) info = yes

  # check file subtraction and format
  icheckfile(if1,verbose=no)

  # check if the first flat field needs to be post-pre subtracted
  if ( ! icheckfile.subtract )
    {
    diffile = mktemp (tmpdir//"/ibpmgenerate")
    
    # calculate post-pre image
    iframediff (input=if1,
                output=diffile,
                subdark=no,
                flatfield=no,
                subsky=no,
                wcs=no,
                verbose=verbose,
                info=info,
                tmpdir=tmpdir)
    if1 = diffile
    bf1 = yes
    }

  # check file subtraction and format
  icheckfile(if2,verbose=no)

  # check if the second flat field needs to be post-pre subtracted
  if ( ! icheckfile.subtract )
    {
    diffile = mktemp (tmpdir//"/ibpmgenerate")
    
    # calculate post-pre image
    iframediff (input=if2,
                output=diffile,
                subdark=no,
                flatfield=no,
                subsky=no,
                wcs=no,
                verbose=verbose,
                info=info,
                tmpdir=tmpdir)
    if2 = diffile
    bf2 = yes
    }

  # find ratio of flats
  if ( info ) print ("calculating image ratio ...")
  diffile = mktemp (tmpdir//"/ibpmgenerate")
  imarith(operand1=if1,
          op="/",
          operand2=if2,
          result=diffile,
          title="Flat Field Ratio",
          divzero=0.,
          hparams="",
          pixtype="",
          calctype="",
          verbose=verbose,
          noact=no)

  # call ccdmask to calculate bad pixel mask

  if ( info ) print ("generating bad pixel mask ...")
  ccdmask(\
        image = diffile,
         mask = output,
        ncmed = 7,
        nlmed = 7,
        ncsig = 15,
        nlsig = 15,
       lsigma = 6.,
       hsigma = 6.,
        ngood = 2,
      linterp = 1,
      cinterp = 2,
     eqinterp = 3)

  # delete temporary images and files
  if ( bf1 ) imdelete(if1,yes,verify=no)
  if ( bf2 ) imdelete(if2,yes,verify=no)
  imdelete(diffile,yes,verify=no)

end
