# icheckfile - checks if image is post-pre subtracted, UltraDAS or Imp. B
# Author     : Robert Greimel (greimel@ing.iac.es)
# Last Change: 17. Dec. 2000
##############################################################################
procedure icheckfile(input)

file	input		{prompt="Input image"}
bool	subtract	{prompt="post-pre check result"}
string	format		{prompt="format result"}
int	nimages		{prompt="number of extensions in file"}
int	nwindows	{prompt="number of windows in file"}
bool	verbose		{prompt="Verbose ?"}

begin

  string	imgname,shct,siqlpp
  int		naxis,spos

  # copy input arguments to force definition at the beginning of the script
  imgname=input

  # default output values
  subtract = no
  format = "unknown"
  nimages = 0
  nwindows = 0

  # strip any section information [...] from the filename
  spos = stridx("[",imgname)
  if ( spos > 1 )
    {
    imgname = substr(imgname,1,spos-1)
    }

  #####
  # find necessary information to destinguish DAS cases
  #####

  # find number of extensions in file
  imextensions(input = imgname,
               output = "none",
               index = "1-",
               extname = "",
               extver = "" )
  nimages = imextensions.nimages

  # I should use HCTVERSI= 'IMPB ISP V1.14    ' to check if IMPB
  hselect(images=imgname//"[0]", fields="HCTVERSI", expr="yes") | scanf("%s",shct)

  # only ImpB images should be 3D ...
  imgets(image=imgname//"[0]", param="i_naxis")
  naxis = int(imgets.value)

  # clear cut case, this is an ImpB image
  if ( substr(shct, 2, 5) == "IMPB" && nimages <= 0 )
    {
    format = "ImpB"
    }
  # clear cut case, this is an UDAS image
  if ( substr(shct, 2, 5) != "IMPB" && nimages > 0 )
    {
    format = "UDAS"
    }
  # problem case. Could be ImpB with missing header but very likely is
  # processed UDAS, now without extensions.
  if ( substr(shct, 2, 5) != "IMPB" && nimages <= 0 )
    {
    # There is one more check we can do. If the dimension of the data is 3,
    # then it should be an ImpB image. If it is 2, then it is likely UDAS ...
    if ( naxis == 3 )
      {
      format = "ImpB"
      }
    else
      {
      format = "UDAS"
      }
    }
  # problem case. ImpB should not have any extension !
  if ( substr(shct, 2, 5) == "IMPB" && nimages > 0 )
    {
    format = "ImpB"
    }

  # check if image is already post-pre subtracted
  #   For implementation B images this is the case if the image has two axis.
  #   For IR-UltraDAS this is the case if there are no extensions present.

  # for ImpB, check number of axis to see if the image was post-pre subtracted
  if ( format == "ImpB" )
    {
    if (naxis == 2)
      {
      subtract = yes
      }
    }
  # for UltraDAS, check if either the image header IQL-PP is set to T
  # (this is done by iframediff) or if the number of image extensions
  # is 0.
  if ( format == "UDAS" )
    {
    hselect(images=imgname//"[0]", fields="IQL-PP", expr="yes") | scanf("%s",siqlpp)
    if ( imgets.value == "T" )
      {
      subtract = yes
      }
    else
      {
      if ( nimages <= 0 ) { subtract = yes }
      }
    # UltraDAS also allows windowing. Read the number of windows from
    # the header.
    imgets(image=imgname//"[0]", param="NWINDOWS")
    nwindows = int(imgets.value)
    }

  if ( verbose )
    {
    if ( subtract )
      print (imgname//" is a post-pre subtracted image")
    else
      print (imgname//" has not been post-pre subtracted")

    print (imgname//" is an "//format//" image")
    print (imgname//" has "//nimages//" extensions")
    print (imgname//" has "//nwindows//" windows")
    }

end
