# icombine - combine images
# Author : Robert Greimel (greimel@ing.iac.es)
# Version: 08. Jul. 2001
##############################################################################
procedure icombine(input,output)

string	input	{prompt="List of sky exposures"}
string	output	{prompt="Name of output file"}
bool    subdark	{prompt="Subtract Dark ?"}
file    darkimg	{prompt="Dark Image"}
bool	verbose	{prompt="Verbose ?"}
bool	info	{prompt="Information messages ?"}
string	tmpdir	{prompt="temporary directory for file conversion"}
# imcombine parameters
string	rejmask	{prompt="List of rejection masks (optional)"}
string	plfile	{prompt="List of pixel list files (optional)"}
string	sigma	{prompt="List of sigma images (optional)"}
string	logfile	{prompt="Log file"}
string	combine	{prompt="Type of combine operation"}
string	reject	{prompt="Type of rejection"}
bool	project	{prompt="Project highest dimension of input images?"}
string	outtype	{prompt="Output image pixel datatype"}
file	offsets	{prompt="Input image offsets"}
string	masktype	{prompt="Mask type"}
real	maskvalue	{prompt="Mask value"}
real	blank	{prompt="Value if there are no pixels"}
string	scale	{prompt="Image scaling"}
string	zero	{prompt="Image zero point offset"}
string	weight	{prompt="Image weights"}
string	statsec	{prompt="Image section for computing statistics"}
string	expname	{prompt="Image header exposure time keyword"}
real	lthreshold	{prompt="Lower threshold"}
real	hthreshold	{prompt="Upper threshold"}
int	nlow	{prompt="minmax: Number of low pixels to reject"}
int	nhigh	{prompt="minmax: Number of high pixels to reject"}
int	nkeep	{prompt="Minimum to keep (pos) or maximum to reject (neg)"}
bool	mclip	{prompt="Use median in sigma clipping algorithms?"}
real	lsigma	{prompt="Lower sigma clipping factor"}
real	hsigma	{prompt="Upper sigma clipping factor"}
string	rdnoise	{prompt="ccdclip: CCD readout noise (electrons)"}
string	gain	{prompt="ccdclip: CCD gain (electrons/DN)"}
string	snoise	{prompt="ccdclip: Sensitivity noise (fraction)"}
real	sigscale	{prompt="Tolerance for sigma clipping scaling corrections"}
real	pclip	{prompt="pclip: Percentile clipping parameter"}
real	grow	{prompt="Radius (pixels) for neighbor rejection"}

string	*list1	{prompt="Ignore this parameter(list1)"}

begin
  string	ini,ino
  string	logf,fname,diffile
  file		tmpl,inli,deli,btmp

  # copy input arguments to force definition at the beginning of the script
  ini = input
  ino = output

  # decide if to show output
  if ( verbose )
    {
    logf = "STDOUT"
    info = yes
    }
  else
    {
    logf = logfile
    }

  # check if output image exists
  imgaccess(ino, verbose=no)
  if ( imgaccess.exists )
    {
    beep
    print("")
    print("ERROR: operation would override output file "//ino)
    print("icombine aborted")
    print("")
    beep
    bye
    }

  # generate unique temporary file base name
  #btmp = mktemp(tmpdir//"iframdiff")
  btmp = mktemp("tmp$icombine")

  # create a unique file for expanding image names given.
  tmpl = btmp//"-tmpl"
  inli = btmp//"-inli"
  deli = btmp//"-deli"

  # expand image name.
  sections(ini,option="fullname",> tmpl)

  # Work through list of input files and check if they are already pre read
  # subtracted images
  list1 = tmpl
  while (fscan(list1, fname) != EOF)
    {
    # check file subtraction and format
    icheckfile(fname,verbose=no)

    # check if file needs to be post-pre subtracted
    if ( icheckfile.subtract )
      {
      print(osfn(fname), >> inli)
      }
    else
      {
      diffile = mktemp (tmpdir//"/icombine")

      # calculate post-pre image
      if (info) print ("calculating post-pre image for "// fname //" ...")
      iframediff (input=fname,
                  output=diffile,
                  subdark=subdark,
                  darkimg=darkimg,
                  subsky=no,
                  flatfield=no,
                  wcs=no,
                  tmpdir=no,
                  verbose=verbose,
                  info=info)
      print(osfn(diffile), >> inli)
      print(osfn(diffile), >> deli)
      }
    }

  # combine images
  if (info) print ("combining images ...")
  imcombine (\
        input = "@"//inli,
       output = ino,
      rejmask = rejmask,
       plfile = plfile,
        sigma = sigma,
      logfile = logf,
      combine = combine,
       reject = reject,
      project = project,
      outtype = outtype,
      offsets = offsets,
     masktype = masktype,
    maskvalue = maskvalue,
        blank = blank,
        scale = scale,
         zero = zero,
       weight = weight,
      statsec = statsec,
      expname = expname,
   lthreshold = lthreshold,
   hthreshold = hthreshold,
         nlow = nlow,
        nhigh = nhigh,
        nkeep = nkeep,
        mclip = mclip,
       lsigma = lsigma,
       hsigma = hsigma,
      rdnoise = rdnoise,
         gain = gain,
       snoise = snoise,
     sigscale = sigscale,
        pclip = pclip,
         grow = grow)

  # delete temporary images and files
  delete(tmpl,yes,verify=no)
  delete(inli,yes,verify=no)
  if ( access(deli) )
    {
    imdelete("@"//deli,yes,verify=no)
    delete(deli,yes,verify=no)
    }

end
