# ifileinfo - finds useful information from file header
# Author     : Robert Greimel (greimel@ing.iac.es)
# Last Change: 21. Aug. 2000
##############################################################################
procedure ifileinfo(input)

file	input		{prompt="Input image"}
real	exptim		{prompt="exposure time (result)"}
int	coadd		{prompt="number of coadds (result)"}
int	mndr		{prompt="number of MNDR reads (result)"}
int	naxis1		{prompt="size of first dimension (result)"}
int	naxis2		{prompt="size of second dimension (result)"}
bool	verbose		{prompt="Verbose ?"}

begin

  string	imgname
  int		naxis

  # copy input arguments to force definition at the beginning of the script
  imgname=input

  # default output values
  exptim = 0.
  coadd = 0
  mndr = 0
  naxis1 = 0
  naxis2 = 0

  # check file format
  icheckfile(imgname,verbose=no)

  #####
  # find information for different file formats
  #####

  if ( icheckfile.format == "ImpB" )
    {
    imgets(image=imgname, param="EXPTIM")
    exptim = real(imgets.value)
    imgets(image=imgname, param="INGNR")
    mndr = int(imgets.value)
    imgets(image=imgname, param="INGNC")
    coadd = int(imgets.value)
    imgets (image=imgname, param="i_naxis1")
    naxis1 = int(imgets.value)
    imgets (image=imgname, param="i_naxis2")
    naxis2 = int(imgets.value)
    }

  if ( icheckfile.format == "UDAS" )
    {
    imgets(image=imgname//"[2]", param="EXPTIME")
    exptim = real(imgets.value)
    imgets(image=imgname//"[1]", param="EXPTIME")
    exptim = exptim - real(imgets.value)
    imgets(image=imgname//"[0]", param="COAVERAG")
    coadd = int(imgets.value)
    imgets(image=imgname//"[0]", param="NUMREADS")
    mndr = int(imgets.value)

    # find size of image. This can be a bit more tricky. The problem is what to
    # report if there are windows around ? As iframediff will generate a frame
    # with the full area we will just report the full detector size.
    # How to check if windows are around ? Currently I assume that when there
    # are more than 2 image extensions then windows are there. This check will
    # have to be refined once the read-out-ramp is implemented.
    if ( icheckfile.nimages > 2 )
      {
      # should check for HAWAII-1 detector ...
      naxis1 = 1024
      naxis2 = 1024
      }
    else if ( icheckfile.nimages > 0 )
      {
      imgets (image=imgname//"[1]", param="i_naxis1")
      naxis1 = int(imgets.value)
      imgets (image=imgname//"[1]", param="i_naxis2")
      naxis2 = int(imgets.value)
      }
    else
      {
      imgets (image=imgname, param="i_naxis1")
      naxis1 = int(imgets.value)
      imgets (image=imgname, param="i_naxis2")
      naxis2 = int(imgets.value)
      }
    }

  #####
  # inform user about values if requested
  #####

  if ( verbose )
    {
    print (imgname//" : exposure time    : "//exptim)
    print (imgname//" : number of coadds : "//coadd)
    print (imgname//" : number of MNDR   : "//mndr)
    print (imgname//" : naxis1           : "//naxis1)
    print (imgname//" : naxis2           : "//naxis2)
    }

end
