# ifindlin - Plot linearity data using cps info.
# Author : Peter Moore, adapted from ifinddark by Robert Greimel (greimel@ing.iac.es)
# Version: 18. Dec. 2000
##############################################################################
procedure ifindlin(input)

string	input		{prompt="List of images"}
real    corr = 0.296    {prompt="value of integration time correction in secs"}
real    clip = 3	{prompt="clipping factor in sigma"}
bool	verbose		{prompt="verbose"}

string *list1	{prompt="Ignore this parameter(list1)"}

begin
  string	ini
  string	fname,instr,sfname
  file		tmpi,tmpl,timf,tmpp
  real		etime,m,s,f,p,m_tot,et_tot

  # copy input arguments to force definition at the beginning of the script
  ini = input

  # create unique filenames for temporary files
  tmpi = mktemp("tmp$ifindlin")
  tmpl = mktemp("tmp$ifindlin")
  timf = mktemp("tmp$ifindlin")

  # expand image name.
  sections(ini,option="fullname",> tmpl)
 
  # Work through list of input files
  list1 = tmpl
  
  #clear average registers
  m_tot = 0
  et_tot = 0
  
  while (fscan(list1, fname) != EOF)
    {
    # find exposure time
    ifileinfo(input=fname, verbose=no)
    etime = ifileinfo.exptim
 
    # check file subtraction and format
    icheckfile(fname,verbose=no)

    # check if data file needs to be post-pre subtracted
    if ( icheckfile.subtract )
      {
      sfname = fname
      }
    else
      {
      # delete previous temporary image
      imdel(images=tmpi, go_ahead=yes, verify=no, >>& "/dev/null")

      # calculate post-pre image
      print ("calculating post-pre for image "//fname//" ...")
      iframediff (input = fname,
                  output = tmpi,
                  subdark = no,
                  flatfield = no,
                  subsky = no,
                  wcs = no,
                  verbose = no,
                  info = no )
      sfname = tmpi
      }

    # calculate statistics
    imstatistics (sfname,
                  fields="midpt,stddev",
                  lower=INDEF,
                  upper=INDEF,
                  binwidth=0.1,
                  format=no) | scanf("%f %f",m,s)

    # re-calculate statistics with sigma clipping
    imstatistics (sfname,
                  fields="mean,stddev",
                  lower=(m - clip*s),
                  upper=(m + clip*s),
                  binwidth=0.1,
                  format=no) | scanf("%f %f",m,s)

    # adjust the exposure time to compensate for flush read timing.
    etime = etime + corr
    m_tot = m_tot + m
    et_tot = et_tot + etime 

    # write mean and ADU / sec to temporary file
    print(m//" "//(m / etime), >> timf)

    # print verbose information
    if ( verbose ) print(fname//" : "//etime//" "//m//" "//s//" "//(m / etime))
    }

  # sort mean values into order
  del(tmpl,yes,verify=no)
  sort(input_file = timf,
       column = 0,
       ignore_white = no,
       numeric_sort = yes,
       reverse_sort = no,
       > tmpl)
  # calculate cps baseline
  m_tot = m_tot / et_tot
    
  del(timf,yes,verify=no)
  list1 = tmpl

  # calculate percent deviation from mean cps
  while(fscan(list1,m,s) != EOF)
  {
    print(m//" "//(s - m_tot) / m_tot * 100, >> timf)
    if ( verbose ) print(m//" "//(s - m_tot) / m_tot * 100//"%")
  }
    
  # graph the result (line plot)
  graph(input=timf,
        wx1=0.,
        wx2=0.,
        wy1=0.,
        wy2=0.,
        wcs="logical",
        axis=1,
        transpose=no,
        pointmode=no,
        marker="box",
        szmarker=0.005,
        ltypes="",
        colors="",
        logx=no,
        logy=no,
        box=yes,
        ticklabels=yes,
        xlabel="Mean ADU",
        ylabel="Percent Deviation",
        xformat="wcsformat",
        yformat="",
        title="INGRID Linearity Plot",
        lintran=no,
        p1=0.,
        p2=0.,
        q1=0.,
        q2=1.,
        vx1=0.,
        vx2=0.,
        vy1=0.,
        vy2=0.,
        majrx=5,
        minrx=5,
        majry=5,
        minry=5,
        overplot=no,
        append=no,
        device="stdgraph",
        round=no,
        fill=yes)
 
 # graph the result (overplot markers)
  graph(input=timf,
        wx1=0.,
        wx2=0.,
        wy1=0.,
        wy2=0.,
        wcs="logical",
        axis=1,
        transpose=no,
        pointmode=yes,
        marker="box",
        szmarker=0.01,
        ltypes="",
        colors="2",
        logx=no,
        logy=no,
        box=yes,
        ticklabels=yes,
        xlabel="Mean ADU",
        ylabel="Percent Deviation",
        xformat="wcsformat",
        yformat="",
        title="INGRID Linearity Plot",
        lintran=no,
        p1=0.,
        p2=0.,
        q1=0.,
        q2=1.,
        vx1=0.,
        vx2=0.,
        vy1=0.,
        vy2=0.,
        majrx=5,
        minrx=5,
        majry=5,
        minry=5,
        overplot=no,
        append=yes,
        device="stdgraph",
        round=no,
        fill=yes)

  # delete temporary images and files
  imdel(images=tmpi, go_ahead=yes, verify=no, >>& "/dev/null")
  del(tmpl,yes,verify=no, >>& "/dev/null")
  del(timf,yes,verify=no, >>& "/dev/null")

  # clear list variables
  list1 = ""
  
end
