# irefinewcs - refine WCS for (INGRID) image
# Author     : Robert Greimel (greimel@ing.iac.es)
# Last Change: 25. Jul. 2000
##############################################################################
procedure irefinewcs(input)

file	input		{prompt="Input image(s)"}
string	platescale	{prompt="Platescale or Keyword"}
string	ra		{prompt="RA"}
string	dec		{prompt="Dec"}
bool	verbose		{prompt="Verbose ?"}

string *list1           {prompt="Ignore this parameter(list1)"}

begin

  file		tcent,tuser
  string	imgname,detector,key,diffile,junk
  struct        cmd
  int    	wcs,nsc
  real		pixsize,pscale
  real		xmag,ymag,tel_ra,tel_dec,xoff,yoff
  real		x,y

  # copy input arguments
  imgname=input
  pscale = real("0"//platescale)

  # find detector from header information
  imgets (image=imgname, param="DETECTOR")
  detector = imgets.value

  # read and calculate plate scale if necessary
  if ( pscale == 0. )
    {
    imgets (image=imgname, param=platescale)
    pscale = real(imgets.value)
    # check if detector is known and set necessary values
    # pixsize ... pixel size in [m]
    if ( detector == "HAWAII-1" )
      {
      pixsize=0.0000185   # 18.5 mu-m
      }
    else
      {
      print ("Detector : "//detector)
      print ("Sorry - this detector is unknown")
      return
      }
    # calculate scale
    ymag = pscale * pixsize * 3600.
    xmag = -ymag
    }
  else
    {
    ymag = pscale
    xmag = -ymag
    }

  # check file subtraction and format
  icheckfile(imgname,verbose=no)
  # check if file needs to be post-pre subtracted
  if ( icheckfile.subtract )
    {
    diffile = imgname
    }
  else
    {
    # get temporary file name
    iffile = mktemp (tmpdir//"/irefinewcs")
    # calculate post-pre image
    print ("calculating post-pre image ...")
    iframediff (input = imgname,
                output = diffile)
    }

  # display image
  display(diffile,1)

  # mark the star for which the RA and DEC are known
  tcent = mktemp("tmp$irefinewcs")
  tuser = mktemp("tmp$irefinewcs")
  print " *** please mark one star for which RA/DEC is known with 'm'"
  while ( fscan(imcur, x, y, wcs, cmd) != EOF )
    {
    key = substr(cmd, 1, 1)
    if ( key == "m" )
      {
      print("Cursor   : x="//x//" y="//y)
      delete(tuser,yes,verify=no, >>& "/dev/null")
      print(x//" "//y, > tuser)

      imcentroid(input=diffile,
                 reference="",
                 coords=tuser,
                 shifts="",
                 boxsize=7,
                 bigbox=11,
                 negative=no,
                 background=INDEF,
                 lower=INDEF,
                 upper=INDEF,
                 niterate=3,
                 tolerance=0,
                 verbose=no, > tcent)

      # read centroiding information
      list1 = tcent
      nsc = fscan (list1)
      nsc = fscan (list1, junk, x, junk, y)
      list1 = ""

      print("Centroid : x="//x//" y="//y)
      break
      }
    else
      beep
    }

  delete(tcent,yes,verify=no)
  delete(tuser,yes,verify=no)
  if ( diffile != imgname ) imdelete(diffile,yes,verify=no)

  tel_ra = real(ra)
  tel_dec = real(dec)
  if ( verbose )
    {
    print ("RA ="//tel_ra)
    print ("Dec="//tel_dec)
    }

  # set wcs
  # xref,yref ... pixel coordinates of sky reference point (default=center)
  # xmag,ymag ... scale factors in "/pixel
  # xrotaion,yrotation ... rotation angels (counter-clockwise)
  # lngref,latref ... RA,Dec for sky reference point
  # lngunits,latunits ... units [hours|degrees|radians]
  # projection ... sky projection geometry [tan|arc|sin|lin|ait|car|csc|gls|mer|
  #                                         mol|par|pco|qsc|stg|tsc|zea]
  # coosystem ... celectial coordinate system [icrs|j2000|b1950|...]
  ccsetwcs (images=imgname, \
	  database="", \
	  solutions="", \
	  xref=x, \
	  yref=y, \
	  xmag=xmag, \
	  ymag=ymag, \
	  xrotation=INDEF, \
	  yrotation=INDEF, \
	  lngref=tel_ra, \
	  latref=tel_dec, \
#	  lngunits="degrees", \
#	  latunits="degrees", \
	  lngunits=INDEF, \
	  latunits=INDEF, \
	  transpose=no, \
	  projection="tan", \
	  coosystem="j2000", \
	  update=yes, \
	  pixsystem="logical", \
	  verbose=verbose )

end
