# iskyflat - generate flat field from sky images
# Author : Robert Greimel (greimel@ing.iac.es)
# Version: 25. Jul. 2000
##############################################################################
procedure iskyflat(input,output)

string	input	{prompt="List of sky exposures"}
string	output	{prompt="Name of output file"}
bool	subdark	{prompt="Subtract Dark ?"}
file	darkimg	{prompt="Dark Image"}
bool	verbose	{prompt="Verbose ?"}
bool	info	{prompt="Information messages ?"}
string	tmpdir	{prompt="temporary directory for file conversion"}

string	*list1	{prompt="Ignore this parameter(list1)"}

begin
  string	ini,ino
  string	log,fname,diffile,ftmp
  file		tmpl,inli,deli

  # copy input arguments to force definition at the beginning of the script
  ini = input
  ino = output

  # decide if to show output
  if ( verbose )
    {
    log = "STDOUT"
    info = yes
    }
  else
    {
    log = ""
    }

  # create a unique file for expanding image names given.
  tmpl = mktemp("tmp$iskyflat")
  inli = mktemp("tmp$iskyflat")
  deli = mktemp("tmp$iskyflat")

  # expand image name.
  sections(ini,option="fullname",> tmpl)

  # Work through list of input files and check if they are already pre read
  # subtracted images
  list1 = tmpl
  while (fscan(list1, fname) != EOF)
    {
    # check file subtraction and format
    icheckfile(fname,verbose=no)

    # check if image needs to be post-pre subtracted
    if ( ! icheckfile.subtract )
      {
      diffile = mktemp (tmpdir//"/iskyflat")

      # calculate post-pre image
      if (info) print ("calculating post-pre image for "// fname //" ...")
      iframediff (input=fname,
                  output=diffile,
                  subdark=subdark,
                  darkimg=darkimg,
                  subsky=no,
                  flatfield=no,
                  wcs=no,
                  tmpdir=no,
                  verbose=verbose,
                  info=info)
      print(osfn(diffile), >> inli)
      print(osfn(diffile), >> deli)
      }
    else
      {
      print(osfn(fname), >> inli)
      }
    }

  # calculate median of images
  if (info) print ("combining images ...")
  ftmp = mktemp (tmpdir//"/iskyflat")
  imcombine (\
        input = "@"//inli,
       output = ftmp,
      rejmask = "",
       plfile = "",
        sigma = "",
      logfile = log,
      combine = "median",
       reject = "sigclip",
      project = no,
      outtype = "real",
      offsets = "none",
     masktype = "none",
    maskvalue = 0.,
        blank = 1.,
        scale = "mode",
         zero = "none",
       weight = "none",
      statsec = "",
      expname = "EXPTIM",
   lthreshold = INDEF,
   hthreshold = INDEF,
         nlow = 1,
        nhigh = 1,
        nkeep = 1,
        mclip = yes,
       lsigma = 3.,
       hsigma = 3.,
      rdnoise = "0.",
         gain = "1.",
       snoise = "0.",
     sigscale = 0.1,
        pclip = -0.5,
         grow = 0.)

  # devide image by median
  if ( info ) print ("normalizing sky flat ...")
  imexpr("a/median(a)",ino,ftmp,
         dims="auto",intype="auto",outtype="auto",
         refim="auto",verbose=verbose)

  # delete temporary images and files
  imdelete("@"//deli,yes,verify=no)
  imdelete(ftmp,yes,verify=no)
  delete(tmpl,yes,verify=no)
  delete(inli,yes,verify=no)
  delete(deli,yes,verify=no)

end
