# isubtract - subtract two images from each other
# Author : Robert Greimel (greimel@ing.iac.es)
# Version: 29. Mar. 2001
##############################################################################
procedure isubtract(inputr1,inputr2,output)

string	inputr1		{prompt="First exposure"}
string	inputr2		{prompt="Second exposure"}
string	output		{prompt="Output file"}

bool	verbose		{prompt="verbose"}
bool	info		{prompt="info"}

begin
  string	in1,in2,out
  string	title
  file		ftmp1,ftmp2

  #copy input arguments to force definition at the beginning of the script
  in1 = inputr1
  in2 = inputr2
  out = output

  title = in1//" - "//in2
  ftmp1 = ""
  ftmp2 = ""

  # check if first input file is post-pre subtracted
  icheckfile(in1,verbose=no)

  # do post-pre subtraction if necessary
  if ( !icheckfile.subtract )
    {
    # generate unique temporary file name
    ftmp1 = mktemp ("tmp$isubtract")
    # calculate post-pre image
    iframediff (\
      in1,
      output=ftmp1,
      subdark=no,
      flatfield=no,
      subsky=no,
      wcs=yes,
      verbose=verbose,
      info=info)

    in1 = ftmp1
    }

  # check if second input file is post-pre subtracted
  icheckfile(in2,verbose=no)

  # do post-pre subtraction if necessary
  if ( !icheckfile.subtract )
    {
    # generate unique temporary file name
    ftmp2 = mktemp ("tmp$isubtract")
    # calculate post-pre image
    iframediff (\
      in2,
      output=ftmp2,
      subdark=no,
      flatfield=no,
      subsky=no,
      wcs=yes,
      verbose=verbose,
      info=info)

    in2 = ftmp2
    }

  # subtract images
  imarith (in1, "-", in2, out,
           title=title,
           divzero=0., hparams="", pixtype="", calctype="",
           verbose=no, noact=no)

  # remove temporary images
  if ( ftmp1 != "" )
    {
    imdelete(images=ftmp1,go_ahead=yes,verify=no, >>& "dev$null")
    }
  if ( ftmp2 != "" )
    {
    imdelete(images=ftmp2,go_ahead=yes,verify=no, >>& "dev$null")
    }

end
