# itabplot - helper routine for ifindlin to plot graphs from tables
# Author : Robert Greimel (greimel@ing.iac.es)
# Version: 01. Apr. 2001
##############################################################################
procedure itabplot (itable1,col1,itable2,col2)

string	itable1		{prompt="Name of first table"}
string	col1		{prompt="Names of columns to plot (x y)"}
string	itable2		{prompt="Name of second table"}
string	col2		{prompt="Names of columns to plot (x y)"}

string	title		{prompt="Graph title"}
string	xlabel		{prompt="Graph x-axis label"}
string	ylabel		{prompt="Graph y-axis label"}

bool	point		{prompt="Plot points"}
bool	line		{prompt="Plot lines"}
bool	pavg		{prompt="Plot average"}
bool	xerr		{prompt="Plot x-axis error"}
bool	yerr		{prompt="Plot y-axis error"}

begin
  string	xcol1,xcol2,ycol1,ycol2,tmptab,tmptab2
  int		ip
  real		xmin,xmax,ymin,ymax

  # check if we need to plot anything ...
  if ( !point && !line ) goto ende

  # find x and y column names
  # this depends on having 1 (and only 1) space separating the two column names
  ip = stridx(" ",col1)
  xcol1 = substr(col1, 1, ip-1)
  ycol1 = substr(col1, ip+1, strlen(col1))

  ip = stridx(" ",col2)
  xcol2 = substr(col2, 1, ip-1)
  ycol2 = substr(col2, ip+1, strlen(col2))

  # set plot and axis titles
  axispar.title = title
  axispar.xlabel = xlabel
  axispar.ylabel = ylabel

  # make sure error axis is off
  pltpar.erraxis = 0

  # zero axis scaling
  xmin = 0.
  xmax = 0.
  ymin = 0.
  ymax = 0.

  if ( pavg )
    {
    ############################################################
    # Plot Average and use the difference of the measured values
    # as error estimates.

    # create temporary table
    tmptab = mktemp ("tmp$itabplot")
    tmptab2 = tmptab//"_t2.tab"
    tmptab = tmptab//".tab"

    # copy plotted columns from the input table(s) to the temporary table
    tcopy(intable = itable1//"[c:"//xcol1//","//ycol1//"]", \
          outtable = tmptab2, \
          verbose = no)
    tchcol(table = tmptab2, \
           oldname = xcol1, \
           newname = "x1", \
           newfmt = "", \
           newunits = "", \
           verbose = no)
    tchcol(table = tmptab2, \
           oldname = ycol1, \
           newname = "y1", \
           newfmt = "", \
           newunits = "", \
           verbose = no)
    tmerge(intable = tmptab2//","//itable2//"[c:"//xcol2//","//ycol2//"]", \
           outtable = tmptab, \
           option = "merge", \
           allcols = yes, \
           tbltype = "default", \
           allrows = 100, \
           extracol = 0)
    tchcol(table = tmptab, \
           oldname = xcol2, \
           newname = "x2", \
           newfmt = "", \
           newunits = "", \
           verbose = no)
    tchcol(table = tmptab, \
           oldname = ycol2, \
           newname = "y2", \
           newfmt = "", \
           newunits = "", \
           verbose = no)

    if ( xerr )
      {
      # calculate average of x columns
      tcalc (table = tmptab, \
             outcol = "xavg", \
             equals = "(x1+x2)/2")

      # calculate difference of x columns
      tcalc (table = tmptab, \
             outcol = "xdif", \
             equals = "abs(x1-x2)")

      # calculate min error of x column
      tcalc (table = tmptab, \
             outcol = "xemin", \
             equals = "xavg-xdif")

      # calculate max error of x column
      tcalc (table = tmptab, \
             outcol = "xemax", \
             equals = "xavg+xdif")

      # find x column range
      tstat (intable = tmptab, \
             column = "xemin", \
             outtable = "", \
             lowlim = INDEF,\
             highlim = INDEF )
      xmin = tstat.vmin
      xmax = tstat.vmax

      tstat (intable = tmptab, \
             column = "xemax", \
             outtable = "", \
             lowlim = INDEF,\
             highlim = INDEF )
      if ( tstat.vmin < xmin ) xmin = tstat.vmin
      if ( tstat.vmax > xmax ) xmax = tstat.vmax

      xcol1 = "xavg"
      }
    else
      {
      xcol1 = "x1"
      }

    if ( yerr )
      {
      # calculate average of y columns
      tcalc (table = tmptab, \
             outcol = "yavg", \
             equals = "(y1+y2)/2")

      # calculate difference of y columns
      tcalc (table = tmptab, \
             outcol = "ydif", \
             equals = "abs(y1-y2)")

      # calculate min error of y column
      tcalc (table = tmptab, \
             outcol = "yemin", \
             equals = "yavg-ydif")

      # calculate max error of y column
      tcalc (table = tmptab, \
             outcol = "yemax", \
             equals = "yavg+ydif")

      # find y column range
      tstat (intable = tmptab, \
             column = "yemin", \
             outtable = "", \
             lowlim = INDEF,\
             highlim = INDEF )
      ymin = tstat.vmin
      ymax = tstat.vmax

      tstat (intable = tmptab, \
             column = "yemax", \
             outtable = "", \
             lowlim = INDEF,\
             highlim = INDEF )
      if ( tstat.vmin < ymin ) ymin = tstat.vmin
      if ( tstat.vmax > ymax ) ymax = tstat.vmax

      ycol1 = "yavg"
      }
    else
      {
      ycol1 = "y1"
      }

    # set plot borders, etc.
    axispar.wl = xmin
    axispar.wr = xmax
    axispar.wb = ymin
    axispar.wt = ymax
    dvpar.append = no

    # plot average
    pltpar.crvcolor = 2
    if ( line )
      {
      pltpar.pointmode = no
      sgraph (tmptab//" "//xcol1//" "//ycol1)
      dvpar.append = yes
      }
    if ( point )
      {
      pltpar.pointmode = yes
      sgraph (tmptab//" "//xcol1//" "//ycol1)
      dvpar.append = yes
      }

    # plot y error bars
    if ( xerr )
      {
      pltpar.pointmode = no
      pltpar.erraxis = 1
      pltpar.errtype = "bartck"
      sgraph (tmptab//" "//xcol1//" "//ycol1,errcolumn="xdif")
      }

    # plot y error bars
    if ( yerr )
      {
      pltpar.pointmode = no
      pltpar.erraxis = 2
      pltpar.errtype = "bartck"
      sgraph (tmptab//" "//xcol1//" "//ycol1,errcolumn="ydif")
      }

    # remove temporary table
    delete(tmptab2,yes,verify=no)
    delete(tmptab,yes,verify=no)
    }
  else
    {
    ############################################################
    # Plot both curves on top of each other

    # find x column range
    tstat (intable = itable1, \
           column = xcol1, \
           outtable = "", \
           lowlim = INDEF,\
           highlim = INDEF )
    xmin = tstat.vmin
    xmax = tstat.vmax

    tstat (intable = itable2, \
           column = xcol2, \
           outtable = "", \
           lowlim = INDEF,\
           highlim = INDEF )
    if ( tstat.vmin < xmin ) xmin = tstat.vmin
    if ( tstat.vmax > xmax ) xmax = tstat.vmax

    # find y column range
    tstat (intable = itable1, \
           column = ycol1, \
           outtable = "", \
           lowlim = INDEF,\
           highlim = INDEF )
    ymin = tstat.vmin
    ymax = tstat.vmax

    tstat (intable = itable2, \
           column = ycol2, \
           outtable = "", \
           lowlim = INDEF,\
           highlim = INDEF )
    if ( tstat.vmin < ymin ) ymin = tstat.vmin
    if ( tstat.vmax > ymax ) ymax = tstat.vmax

    # set plot borders, etc.
    axispar.wl = xmin
    axispar.wr = xmax
    axispar.wb = ymin
    axispar.wt = ymax
    dvpar.append = no

    # plot first exposure set
    pltpar.crvcolor = 3
    if ( line )
      {
      pltpar.pointmode = no
      sgraph (itable1//" "//col1)
      dvpar.append = yes
      }
    if ( point )
      {
      pltpar.pointmode = yes
      sgraph (itable1//" "//col1)
      dvpar.append = yes
      }

    # plot second exposure set
    pltpar.crvcolor = 4
    if ( line )
      {
      pltpar.pointmode = no
      sgraph (itable2//" "//col2)
      }
    if ( point )
      {
      pltpar.pointmode = yes
      sgraph (itable2//" "//col2)
      }
    }

  # reset some plot values before leaving
ende:
  axispar.wl = 0.
  axispar.wr = 0.
  axispar.wb = 0.
  axispar.wt = 0.
  pltpar.crvcolor = INDEF
  pltpar.pointmode = no
  pltpar.erraxis = 0
  dvpar.append = no

  # The End

end
